<?php
/*
Plugin Name: Custom Field Menu
Plugin URL: http://clement-decou.olympe.in
Description: Add custom fields to menu items
Version: 0.2.5.1
Author: Clément Décou
Author URI: http://clement-decou.olympe.in
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/
require_once(plugin_dir_path( __FILE__ ).'/classes/admin/PluginAdminPage.php');
class custom_field_menu {

	/*--------------------------------------------*
	 * Constructor
	 *--------------------------------------------*/

	/**
	 * Initializes the plugin by setting localization, filters, and administration functions.
	 */
	function __construct() {

		register_activation_hook(__FILE__, array($this, 'cfm_init'));

		// load the plugin translation files
		add_action( 'init', array( $this, 'textdomain' ) );
		
		// add custom menu fields to menu
		add_filter( 'wp_setup_nav_menu_item', array( $this, 'cfm_add_custom_nav_fields' ) );

		//Edit the walker if force
		add_filter( 'wp_nav_menu_args', array($this, 'cfm_modify_nav_menu_args' ));

		// save menu custom fields
		add_action( 'wp_update_nav_menu_item', array( $this, 'cfm_update_custom_nav_fields'), 10, 3 );
		
		// edit menu walker
		add_filter( 'wp_edit_nav_menu_walker', array( $this, 'cfm_edit_walker'), 10, 2 );

		add_action('admin_enqueue_scripts', array($this, 'cfm_load_media'));

		add_action('admin_menu', array($this, 'cfm_admin_menu'));
		add_action('admin_init', array($this, 'cfm_register_settings'));


	} // end constructor

	/**
	 * Init the plugin (options etc.)
	 *
	 * @access      public
	 * @since       0.2 
	 * @return      void
	*/

	function cfm_init(){
		PluginAdminPage::defaultOption();
	}

	/**
	 * Edit the args of wp_nav_menu
	 *
	 * @access      public
	 * @since       0.2.5 
	 * @return      void
	*/
	function cfm_modify_nav_menu_args( $args ){
		if(get_option('force_using_walker') == 1){
			$args['walker'] = new cfm_walker;
		}
		return $args;
	}


	/**
	 * Load files for media library
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function cfm_load_media(){
		global $pagenow;
		if($pagenow == "nav-menus.php"){
			wp_enqueue_media();
			wp_register_script('cfm-admin-js', WP_PLUGIN_URL.'/custom-field-menu/js/cfm_script.js', array('jquery'));
			$titleBox = (get_option('title_box') != '') ? get_option('title_box') : 'Choose an image';
			$txtButton = (get_option('text_button') != '') ? get_option('text_button') : 'Choose';
			wp_localize_script('cfm-admin-js', 'titleBox', $titleBox );
			wp_localize_script('cfm-admin-js', 'textButton', $txtButton );
        	wp_enqueue_script('cfm-admin-js');
		}
	}
	
	/**
	 * Load the plugin's text domain
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	public function textdomain() {
		load_plugin_textdomain( 'cfm_scm', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
	}
	
	/**
	 * Add custom fields to $item nav object
	 * in order to be used in custom Walker
	 *
	 * @access      public
	 * @since       1.0 
	 * @return      void
	*/
	function cfm_add_custom_nav_fields( $menu_item ) {
	
	    $menu_item->urlimg = get_post_meta( $menu_item->ID, '_menu_item_urlimg', true );
	    return $menu_item;
	    
	}
	
	/**
	 * Save menu custom fields
	 *
	 * @access      public
	 * @since       1.0 
	 * @return      void
	*/
	function cfm_update_custom_nav_fields( $menu_id, $menu_item_db_id, $args ) {
	
	    // Check if element is properly sent
	    if ( is_array( $_REQUEST['menu-item-urlimg']) ) {
	        $url_value = $_REQUEST['menu-item-urlimg'][$menu_item_db_id];
	        update_post_meta( $menu_item_db_id, '_menu_item_urlimg', $url_value );
	    }
	    
	}
	
	/**
	 * Define new Walker edit
	 *
	 * @access      public
	 * @since       1.0 
	 * @return      void
	*/
	function cfm_edit_walker($walker,$menu_id) {
	    return 'Walker_Nav_Menu_Edit_Custom';
	}

	/**
	 * Add admin menu
	 *
	 * @access      public
	 * @since       0.2 
	 * @return      void
	*/
	function cfm_admin_menu(){
		new PluginAdminPage();
	}

	/**
	 * Register all settings of the plugin
	 *
	 * @access      public
	 * @since       0.2 
	 * @return      void
	*/
	function cfm_register_settings(){
		PluginAdminPage::setupOption();
	}

}

// instantiate plugin's class
$GLOBALS['custom_field_menu'] = new custom_field_menu();


include_once( 'edit_custom_walker.php' );
include_once( 'custom_walker.php' );